Method: Debugger.stop
- Defined in:
- ext/ruby_debug.c
.stop ⇒ Boolean
This method disacivates the debugger. It returns true if the debugger is disacivated, otherwise it returns false.
Note that if you want to stop debugger, you must call Debugger.stop as many time as you called Debugger.start method.
984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'ext/ruby_debug.c', line 984
static VALUE
debug_stop(VALUE self)
{
debug_check_started();
start_count--;
if(start_count)
return Qfalse;
rb_remove_event_hook(debug_event_hook);
locker = Qnil;
breakpoints = Qnil;
threads_tbl = Qnil;
return Qtrue;
}
|