Class: Debugger::Breakpoint
- Inherits:
-
Object
- Object
- Debugger::Breakpoint
- Defined in:
- ext/ruby_debug.c
Instance Method Summary collapse
-
#expr ⇒ String
Returns a codition expression when this breakpoint should be activated.
-
#pos ⇒ String, Integer
Returns a position of this breakpoint.
-
#source ⇒ String
Returns a source of the breakpoint.
Instance Method Details
#expr ⇒ String
Returns a codition expression when this breakpoint should be activated.
1319 1320 1321 1322 1323 1324 1325 1326 |
# File 'ext/ruby_debug.c', line 1319
static VALUE
breakpoint_expr(VALUE self)
{
debug_breakpoint_t *breakpoint;
Data_Get_Struct(self, debug_breakpoint_t, breakpoint);
return breakpoint->expr;
}
|
#pos ⇒ String, Integer
Returns a position of this breakpoint.
1304 1305 1306 1307 1308 1309 1310 1311 |
# File 'ext/ruby_debug.c', line 1304
static VALUE
breakpoint_pos(VALUE self)
{
debug_breakpoint_t *breakpoint;
Data_Get_Struct(self, debug_breakpoint_t, breakpoint);
return breakpoint->pos;
}
|
#source ⇒ String
Returns a source of the breakpoint.
1289 1290 1291 1292 1293 1294 1295 1296 |
# File 'ext/ruby_debug.c', line 1289
static VALUE
breakpoint_source(VALUE self)
{
debug_breakpoint_t *breakpoint;
Data_Get_Struct(self, debug_breakpoint_t, breakpoint);
return breakpoint->source;
}
|